@@ -69,6 +69,7 @@ class PROJ_GCC_DLL Datum : public common::ObjectUsage,
     //! @endcond
 
     PROJ_DLL const util::optional<std::string> &anchorDefinition() const;
+    PROJ_DLL const util::optional<common::Measure> &anchorEpoch() const;
     PROJ_DLL const util::optional<common::DateTime> &publicationDate() const;
     PROJ_DLL const common::IdentifiedObjectPtr &conventionalRS() const;
 
@@ -91,6 +92,8 @@ class PROJ_GCC_DLL Datum : public common::ObjectUsage,
 
   protected:
     PROJ_INTERNAL void setAnchor(const util::optional<std::string> &anchor);
+    PROJ_INTERNAL void
+    setAnchorEpoch(const util::optional<common::Measure> &anchorEpoch);
 
     PROJ_INTERNAL void
     setProperties(const util::PropertyMap
@@ -148,6 +151,9 @@ class PROJ_GCC_DLL DatumEnsemble final : public common::ObjectUsage,
     PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
         const override; // throw(io::FormattingException)
 
+    PROJ_INTERNAL static std::string
+    ensembleNameToNonEnsembleName(const std::string &s);
+
     PROJ_FOR_TEST DatumNNPtr
     asDatum(const io::DatabaseContextPtr &dbContext) const;
     //! @endcond
@@ -335,7 +341,8 @@ class PROJ_GCC_DLL Ellipsoid final : public common::IdentifiedObject,
                         //! @endcond
 
     PROJ_INTERNAL static std::string
-    guessBodyName(const io::DatabaseContextPtr &dbContext, double a);
+    guessBodyName(const io::DatabaseContextPtr &dbContext, double a,
+                  const std::string &ellpsName = std::string());
 
     PROJ_INTERNAL bool lookForProjWellKnownEllps(std::string &projEllpsName,
                                                  std::string &ellpsName) const;
@@ -414,6 +421,12 @@ class PROJ_GCC_DLL GeodeticReferenceFrame : public Datum {
            const util::optional<std::string> &anchor,
            const PrimeMeridianNNPtr &primeMeridian);
 
+    PROJ_DLL static GeodeticReferenceFrameNNPtr
+    create(const util::PropertyMap &properties, const EllipsoidNNPtr &ellipsoid,
+           const util::optional<std::string> &anchor,
+           const util::optional<common::Measure> &anchorEpoch,
+           const PrimeMeridianNNPtr &primeMeridian);
+
     PROJ_DLL static const GeodeticReferenceFrameNNPtr
         EPSG_6267; // North American Datum 1927
     PROJ_DLL static const GeodeticReferenceFrameNNPtr
@@ -584,6 +597,13 @@ class PROJ_GCC_DLL VerticalReferenceFrame : public Datum {
            const util::optional<RealizationMethod> &realizationMethodIn =
                util::optional<RealizationMethod>());
 
+    PROJ_DLL static VerticalReferenceFrameNNPtr
+    create(const util::PropertyMap &properties,
+           const util::optional<std::string> &anchor,
+           const util::optional<common::Measure> &anchorEpoch,
+           const util::optional<RealizationMethod> &realizationMethodIn =
+               util::optional<RealizationMethod>());
+
     //! @cond Doxygen_Suppress
     PROJ_INTERNAL bool _isEquivalentTo(
         const util::IComparable *other,
