@@ -1,7 +1,7 @@
-#define PJ_LIB__
-#include <errno.h>
+
 #include "proj.h"
 #include "proj_internal.h"
+#include <errno.h>
 #include <math.h>
 
 /* Note: EPSG Guidance 7-2 describes a Vertical Perspective method (EPSG::9838),
@@ -9,80 +9,73 @@
  * of topocentric origin for the projection plan.
  */
 
-namespace { // anonymous namespace
-enum Mode {
-    N_POLE = 0,
-    S_POLE = 1,
-    EQUIT  = 2,
-    OBLIQ  = 3
-};
-} // anonymous namespace
+namespace pj_nsper_ns {
+enum Mode { N_POLE = 0, S_POLE = 1, EQUIT = 2, OBLIQ = 3 };
+}
 
 namespace { // anonymous namespace
-struct pj_opaque {
-    double  height;
-    double  sinph0;
-    double  cosph0;
-    double  p;
-    double  rp;
-    double  pn1;
-    double  pfact;
-    double  h;
-    double  cg;
-    double  sg;
-    double  sw;
-    double  cw;
-    enum Mode mode;
-    int     tilt;
+struct pj_nsper_data {
+    double height;
+    double sinph0;
+    double cosph0;
+    double p;
+    double rp;
+    double pn1;
+    double pfact;
+    double h;
+    double cg;
+    double sg;
+    double sw;
+    double cw;
+    enum pj_nsper_ns::Mode mode;
+    int tilt;
 };
 } // anonymous namespace
 
 PROJ_HEAD(nsper, "Near-sided perspective") "\n\tAzi, Sph\n\th=";
 PROJ_HEAD(tpers, "Tilted perspective") "\n\tAzi, Sph\n\ttilt= azi= h=";
 
-# define EPS10 1.e-10
+#define EPS10 1.e-10
 
-
-static PJ_XY nsper_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
-    double  coslam, cosphi, sinphi;
+static PJ_XY nsper_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    struct pj_nsper_data *Q = static_cast<struct pj_nsper_data *>(P->opaque);
+    double coslam, cosphi, sinphi;
 
     sinphi = sin(lp.phi);
     cosphi = cos(lp.phi);
     coslam = cos(lp.lam);
     switch (Q->mode) {
-    case OBLIQ:
+    case pj_nsper_ns::OBLIQ:
         xy.y = Q->sinph0 * sinphi + Q->cosph0 * cosphi * coslam;
         break;
-    case EQUIT:
+    case pj_nsper_ns::EQUIT:
         xy.y = cosphi * coslam;
         break;
-    case S_POLE:
-        xy.y = - sinphi;
+    case pj_nsper_ns::S_POLE:
+        xy.y = -sinphi;
         break;
-    case N_POLE:
+    case pj_nsper_ns::N_POLE:
         xy.y = sinphi;
         break;
     }
     if (xy.y < Q->rp) {
-        proj_errno_set(P, PJD_ERR_TOLERANCE_CONDITION);
+        proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
         return xy;
     }
     xy.y = Q->pn1 / (Q->p - xy.y);
     xy.x = xy.y * cosphi * sin(lp.lam);
     switch (Q->mode) {
-    case OBLIQ:
-        xy.y *= (Q->cosph0 * sinphi -
-           Q->sinph0 * cosphi * coslam);
+    case pj_nsper_ns::OBLIQ:
+        xy.y *= (Q->cosph0 * sinphi - Q->sinph0 * cosphi * coslam);
         break;
-    case EQUIT:
+    case pj_nsper_ns::EQUIT:
         xy.y *= sinphi;
         break;
-    case N_POLE:
-        coslam = - coslam;
-        /*-fallthrough*/
-    case S_POLE:
+    case pj_nsper_ns::N_POLE:
+        coslam = -coslam;
+        PROJ_FALLTHROUGH;
+    case pj_nsper_ns::S_POLE:
         xy.y *= cosphi * coslam;
         break;
     }
@@ -97,16 +90,15 @@ static PJ_XY nsper_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forwar
     return xy;
 }
 
-
-static PJ_LP nsper_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
-    double  rh;
+static PJ_LP nsper_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    struct pj_nsper_data *Q = static_cast<struct pj_nsper_data *>(P->opaque);
+    double rh;
 
     if (Q->tilt) {
         double bm, bq, yt;
 
-        yt = 1./(Q->pn1 - xy.y * Q->sw);
+        yt = 1. / (Q->pn1 - xy.y * Q->sw);
         bm = Q->pn1 * xy.x * yt;
         bq = Q->pn1 * xy.y * Q->cw * yt;
         xy.x = bm * Q->cg + bq * Q->sg;
@@ -120,28 +112,28 @@ static PJ_LP nsper_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, invers
         double cosz, sinz;
         sinz = 1. - rh * rh * Q->pfact;
         if (sinz < 0.) {
-            proj_errno_set(P, PJD_ERR_TOLERANCE_CONDITION);
+            proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
             return lp;
         }
         sinz = (Q->p - sqrt(sinz)) / (Q->pn1 / rh + rh / Q->pn1);
         cosz = sqrt(1. - sinz * sinz);
         switch (Q->mode) {
-        case OBLIQ:
+        case pj_nsper_ns::OBLIQ:
             lp.phi = asin(cosz * Q->sinph0 + xy.y * sinz * Q->cosph0 / rh);
             xy.y = (cosz - Q->sinph0 * sin(lp.phi)) * rh;
             xy.x *= sinz * Q->cosph0;
             break;
-        case EQUIT:
+        case pj_nsper_ns::EQUIT:
             lp.phi = asin(xy.y * sinz / rh);
             xy.y = cosz * rh;
             xy.x *= sinz;
             break;
-        case N_POLE:
+        case pj_nsper_ns::N_POLE:
             lp.phi = asin(cosz);
             xy.y = -xy.y;
             break;
-        case S_POLE:
-            lp.phi = - asin(cosz);
+        case pj_nsper_ns::S_POLE:
+            lp.phi = -asin(cosz);
             break;
         }
         lp.lam = atan2(xy.x, xy.y);
@@ -149,24 +141,25 @@ static PJ_LP nsper_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, invers
     return lp;
 }
 
-
-static PJ *setup(PJ *P) {
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
+static PJ *nsper_setup(PJ *P) {
+    struct pj_nsper_data *Q = static_cast<struct pj_nsper_data *>(P->opaque);
 
     Q->height = pj_param(P->ctx, P->params, "dh").f;
 
     if (fabs(fabs(P->phi0) - M_HALFPI) < EPS10)
-        Q->mode = P->phi0 < 0. ? S_POLE : N_POLE;
+        Q->mode = P->phi0 < 0. ? pj_nsper_ns::S_POLE : pj_nsper_ns::N_POLE;
     else if (fabs(P->phi0) < EPS10)
-        Q->mode = EQUIT;
+        Q->mode = pj_nsper_ns::EQUIT;
     else {
-        Q->mode = OBLIQ;
+        Q->mode = pj_nsper_ns::OBLIQ;
         Q->sinph0 = sin(P->phi0);
         Q->cosph0 = cos(P->phi0);
     }
     Q->pn1 = Q->height / P->a; /* normalize by radius */
-    if ( Q->pn1 <= 0 || Q->pn1 > 1e10 )
-        return pj_default_destructor (P, PJD_ERR_INVALID_H);
+    if (Q->pn1 <= 0 || Q->pn1 > 1e10) {
+        proj_log_error(P, _("Invalid value for h"));
+        return pj_default_destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+    }
     Q->p = 1. + Q->pn1;
     Q->rp = 1. / Q->p;
     Q->h = 1. / Q->pn1;
@@ -178,25 +171,25 @@ static PJ *setup(PJ *P) {
     return P;
 }
 
-
-PJ *PROJECTION(nsper) {
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(pj_calloc (1, sizeof (struct pj_opaque)));
-    if (nullptr==Q)
-        return pj_default_destructor (P, ENOMEM);
+PJ *PJ_PROJECTION(nsper) {
+    struct pj_nsper_data *Q = static_cast<struct pj_nsper_data *>(
+        calloc(1, sizeof(struct pj_nsper_data)));
+    if (nullptr == Q)
+        return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
 
     Q->tilt = 0;
 
-   return setup(P);
+    return nsper_setup(P);
 }
 
-
-PJ *PROJECTION(tpers) {
+PJ *PJ_PROJECTION(tpers) {
     double omega, gamma;
 
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(pj_calloc (1, sizeof (struct pj_opaque)));
-    if (nullptr==Q)
-        return pj_default_destructor (P, ENOMEM);
+    struct pj_nsper_data *Q = static_cast<struct pj_nsper_data *>(
+        calloc(1, sizeof(struct pj_nsper_data)));
+    if (nullptr == Q)
+        return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
 
     omega = pj_param(P->ctx, P->params, "rtilt").f;
@@ -207,6 +200,7 @@ PJ *PROJECTION(tpers) {
     Q->cw = cos(omega);
     Q->sw = sin(omega);
 
-    return setup(P);
+    return nsper_setup(P);
 }
 
+#undef EPS10
