@@ -47,8 +47,6 @@ Last update: 2018-10-26
 *
 ***********************************************************************/
 
-#define PJ_LIB_
-
 #include <errno.h>
 #include <math.h>
 
@@ -555,7 +553,7 @@ static PJ *read_convention(PJ *P) {
 }
 
 /***********************************************************************/
-PJ *TRANSFORMATION(helmert, 0) {
+PJ *PJ_TRANSFORMATION(helmert, 0) {
     /***********************************************************************/
 
     struct pj_opaque_helmert *Q;
@@ -698,7 +696,7 @@ PJ *TRANSFORMATION(helmert, 0) {
 }
 
 /***********************************************************************/
-PJ *TRANSFORMATION(molobadekas, 0) {
+PJ *PJ_TRANSFORMATION(molobadekas, 0) {
     /***********************************************************************/
 
     struct pj_opaque_helmert *Q;
